@@ -6,6 +6,10 @@ ggplot2::ggplot
 #' @export
 ggplot2::ggtitle
 
+#' @importFrom ggplot2 guides
+#' @export
+ggplot2::guides
+
 #' @importFrom ggplot2 labs
 #' @export
 ggplot2::labs
@@ -25,3 +29,8 @@ ggplot2::aes
 #' @importFrom ggplot2 ggsave
 #' @export
 ggplot2::ggsave
+
+#' @importFrom ggplot2 scale_y_discrete
+#' @export
+ggplot2::scale_y_discrete
+
